==> drools-serialization-protobuf-7.73.0.Final-sources.jar: org/drools/serialization/protobuf/timers/TimerNodeTimerOutputMarshaller.java <==
/*
 * Copyright (c) 2020. Red Hat, Inc. and/or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.serialization.protobuf.timers;

import org.drools.core.marshalling.impl.MarshallerWriteContext;
import org.drools.core.phreak.PhreakTimerNode.TimerNodeJobContext;
import org.drools.core.time.JobContext;
import org.drools.serialization.protobuf.PersisterHelper;
import org.drools.serialization.protobuf.ProtobufMessages;
import org.drools.serialization.protobuf.ProtobufOutputMarshaller;
import org.drools.serialization.protobuf.TimersOutputMarshaller;

public class TimerNodeTimerOutputMarshaller implements TimersOutputMarshaller {

    @Override
    public ProtobufMessages.Timers.Timer serialize( JobContext jobCtx, MarshallerWriteContext outputCtx) {
        // TimerNodeJobContext
        TimerNodeJobContext tnJobCtx = ( TimerNodeJobContext ) jobCtx;
        ProtobufMessages.Trigger trigger = ProtobufOutputMarshaller.writeTrigger( tnJobCtx.getTrigger(), outputCtx );
        if (trigger != null) {
            return ProtobufMessages.Timers.Timer.newBuilder()
                    .setType( ProtobufMessages.Timers.TimerType.TIMER_NODE )
                    .setTimerNode( ProtobufMessages.Timers.TimerNodeTimer.newBuilder()
                            .setNodeId( tnJobCtx.getTimerNodeId() )
                            .setTuple( PersisterHelper.createTuple( tnJobCtx.getTuple() ) )
                            .setTrigger( trigger )
                            .build() )
                    .build();
        } else {
            return null;
        }
    }
}

==> drools-serialization-protobuf-8.36.0.Final-sources.jar: org/drools/serialization/protobuf/timers/TimerNodeTimerOutputMarshaller.java <==
/*
 * Copyright (c) 2020. Red Hat, Inc. and/or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.serialization.protobuf.timers;

import org.drools.core.marshalling.MarshallerWriteContext;
import org.drools.core.phreak.PhreakTimerNode.TimerNodeJobContext;
import org.drools.core.time.JobContext;
import org.drools.serialization.protobuf.PersisterHelper;
import org.drools.serialization.protobuf.ProtobufMessages;
import org.drools.serialization.protobuf.ProtobufOutputMarshaller;
import org.drools.serialization.protobuf.TimersOutputMarshaller;

public class TimerNodeTimerOutputMarshaller implements TimersOutputMarshaller {

    @Override
    public ProtobufMessages.Timers.Timer serialize( JobContext jobCtx, MarshallerWriteContext outputCtx) {
        // TimerNodeJobContext
        TimerNodeJobContext tnJobCtx = ( TimerNodeJobContext ) jobCtx;
        ProtobufMessages.Trigger trigger = ProtobufOutputMarshaller.writeTrigger( tnJobCtx.getTrigger(), outputCtx );
        if (trigger != null) {
            return ProtobufMessages.Timers.Timer.newBuilder()
                    .setType( ProtobufMessages.Timers.TimerType.TIMER_NODE )
                    .setTimerNode( ProtobufMessages.Timers.TimerNodeTimer.newBuilder()
                            .setNodeId( tnJobCtx.getTimerNodeId() )
                            .setTuple( PersisterHelper.createTuple( tnJobCtx.getTuple() ) )
                            .setTrigger( trigger )
                            .build() )
                    .build();
        } else {
            return null;
        }
    }
}
